"use strict";
var Observable_1 = require("rxjs/Observable");
var ObservableQueryRef_1 = require("./ObservableQueryRef");
var RxObservableQuery_1 = require("../RxObservableQuery");
var assign = require("lodash/assign");
var omit = require("lodash/omit");
require("rxjs/add/operator/switchMap");
require("rxjs/add/observable/combineLatest");
function createWithObservableVariables(options, mapFn) {
    var observableQueryRef = new ObservableQueryRef_1.ObservableQueryRef();
    var varObs = observeVariables(options.variables);
    return new RxObservableQuery_1.RxObservableQuery(observableQueryRef, function (subscriber) {
        var sub = varObs.switchMap(function (newVariables) {
            var cleanOptions = omit(options, 'variables');
            var newOptions = assign(cleanOptions, { variables: newVariables });
            observableQueryRef.setRef(mapFn(newOptions));
            return observableQueryRef.getRef();
        }).subscribe(subscriber);
        return function () { return sub.unsubscribe(); };
    });
}
exports.createWithObservableVariables = createWithObservableVariables;
function observeVariables(variables) {
    var keys = Object.keys(variables);
    return Observable_1.Observable.create(function (observer) {
        Observable_1.Observable.combineLatest(mapVariablesToObservables(variables))
            .subscribe(function (values) {
            var resultVariables = {};
            values.forEach(function (value, i) {
                var key = keys[i];
                resultVariables[key] = value;
            });
            observer.next(resultVariables);
        });
    });
}
exports.observeVariables = observeVariables;
;
function mapVariablesToObservables(variables) {
    return Object.keys(variables)
        .map(function (key) { return getVariableToObservable(variables[key]); });
}
function getVariableToObservable(variable) {
    if (variable instanceof Observable_1.Observable) {
        return variable;
    }
    else if (typeof variable !== 'undefined') {
        return new Observable_1.Observable(function (subscriber) {
            subscriber.next(variable);
        });
    }
    else {
        return new Observable_1.Observable(function (subscriber) {
            subscriber.next(null);
        });
    }
}
//# sourceMappingURL=variables.js.map